<?php

declare(strict_types=1);

namespace Dedi\SyliusAvisVerifiesPlugin\Console;

use Dedi\SyliusAvisVerifiesPlugin\Request\SendOrderRequestInterface;
use Psr\Log\LoggerInterface;
use Sylius\Component\Core\Model\OrderInterface;
use Sylius\Component\Order\Repository\OrderRepositoryInterface;
use Sylius\Component\Shipping\Model\ShipmentInterface;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

class ExportOrdersCommand extends Command
{
    protected static $defaultName = 'dedi-sylius-avis-verifies:export-orders';

    private SendOrderRequestInterface $sendOrderRequest;

    private OrderRepositoryInterface $orderRepository;

    private LoggerInterface $logger;

    public function __construct(
        SendOrderRequestInterface $sendOrderRequest,
        OrderRepositoryInterface $orderRepository,
        LoggerInterface $logger
    ) {
        parent::__construct();

        $this->sendOrderRequest = $sendOrderRequest;
        $this->orderRepository = $orderRepository;
        $this->logger = $logger;
    }

    protected function configure(): void
    {
        $this
            ->setDescription('Send shipped orders to Avis Verifies.')
            ->addArgument('orderId', InputArgument::REQUIRED, 'Id of order to export')
        ;
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $io = new SymfonyStyle($input, $output);

        $orderId = (int) $input->getArgument('orderId');

        /** @var OrderInterface|null $order */
        $order = $this->orderRepository->findOneBy([
            'shippingState' => ShipmentInterface::STATE_SHIPPED,
            'id' => $orderId,
        ]);

        if (null === $order) {
            $message = sprintf('Shipped order with id %d not found', $orderId);
            $io->error($message);
            $this->logger->error($message);

            return 1;
        }

        $this->sendOrderRequest->send($order);

        $io->success(sprintf('Successfully sent order %d', (int) $order->getId()));

        return 0;
    }
}
