<?php

declare(strict_types=1);

namespace Dedi\SyliusAvisVerifiesPlugin\Console;

use Dedi\SyliusAvisVerifiesPlugin\File\FileImporterInterface;
use Dedi\SyliusAvisVerifiesPlugin\File\ValueObject\ImportFile;
use Dedi\SyliusAvisVerifiesPlugin\Import\ReviewFileImporterInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

class ImportReviewsFromFileCommand extends Command
{
    protected static $defaultName = 'dedi-sylius-avis-verifies:import:reviews-from-file';

    private FileImporterInterface $fileImporter;

    private ReviewFileImporterInterface $reviewFileImporter;

    private LoggerInterface $logger;

    public function __construct(
        FileImporterInterface $fileImporter,
        ReviewFileImporterInterface $reviewFileImporter,
        LoggerInterface $logger
    ) {
        parent::__construct();

        $this->fileImporter = $fileImporter;
        $this->reviewFileImporter = $reviewFileImporter;
        $this->logger = $logger;
    }

    protected function configure(): void
    {
        $this
            ->setDescription('Import reviews from Avis Verifies.')
        ;
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $io = new SymfonyStyle($input, $output);

        try {
            /** @var ImportFile[] $files */
            $files = $this->fileImporter->importAll('reviews_product_');
        } catch (\Exception $e) {
            $io->error($e->getMessage());
            $this->logger->error($e->getMessage());

            return 1;
        }

        foreach ($files as $file) {
            try {
                $this->reviewFileImporter->import($file);
                $this->fileImporter->archiveFile($file);
                $io->success('Imported file ' . $file->getRemoteFilePath());
            } catch (\Exception $e) {
                $io->error($e->getMessage());
                $this->logger->error($e->getMessage());
            }
        }

        return 0;
    }
}
